@@ -1,6 +1,6 @@
 # Author: Babak Naimi, naimi.b@gmail.com
-# Date :  July. 2013
-# Version 1.1
+# Date :  July. 2015
+# Version 1.2
 # Licence GPL v3
 
 if (!isGeneric("exclude")) {
@@ -11,8 +11,8 @@ if (!isGeneric("exclude")) {
 setMethod ('exclude' ,signature(x='RasterStack', vif='VIF'),
            function (x,vif,...) {
              n <- names(x)
-             for (i in 1:length(vif@results[,1])) if (!vif@results[i,1] %in% n) stop("One or all variables in VIF are not in the Raster object")
-             x[[vif@results[,1]]]
+             for (i in 1:length(vif@results[,1])) if (!as.character(vif@results[i,1]) %in% n) stop("One or all variables in VIF are not in the Raster object")
+             x[[as.character(vif@results[,1])]]
             }
            )
 
@@ -20,24 +20,24 @@ setMethod ('exclude' ,signature(x='RasterStack', vif='VIF'),
 setMethod ('exclude' ,signature(x='RasterBrick', vif='VIF'),
            function (x,vif,...) {
              n <- names(x)
-             for (i in 1:length(vif@results[,1])) if (!vif@results[i,1] %in% n) stop("One or all variables in VIF are not in the Raster object")
-             brick(x[[vif@results[,1]]])
+             for (i in 1:length(vif@results[,1])) if (!as.character(vif@results[i,1]) %in% n) stop("One or all variables in VIF are not in the Raster object")
+             brick(x[[as.character(vif@results[,1])]])
            }
 )
 
 setMethod ('exclude' ,signature(x='data.frame', vif='VIF'),
            function (x,vif, ...) {
              n <- colnames(x)
-             for (i in 1:length(vif@results[,1])) if (!vif@results[i,1] %in% n) stop("One or all variables in VIF are not in the data.frame object")
-             x[,vif@results[,1]]
+             for (i in 1:length(vif@results[,1])) if (!as.character(vif@results[i,1]) %in% n) stop("One or all variables in VIF are not in the data.frame object")
+             x[,as.character(vif@results[,1])]
            }
 )
 
 setMethod ('exclude' ,signature(x='matrix', vif='VIF'),
            function (x,vif, ...) {
              n <- colnames(x)
-             for (i in 1:length(vif@results[,1])) if (!vif@results[i,1] %in% n) stop("One or all variables in VIF are not in the matrix object")
-             x[,vif@results[,1]]
+             for (i in 1:length(vif@results[,1])) if (!as.character(vif@results[i,1]) %in% n) stop("One or all variables in VIF are not in the matrix object")
+             x[,as.character(vif@results[,1])]
            }
 )
 
@@ -47,7 +47,7 @@ setMethod ('exclude' ,signature(x='RasterStack', vif='missing'),
              if(missing(th)) th <- 10
              vif <- vifstep(x)
              print(vif)
-             if (length(vif@excluded) > 0) x[[vif@results[,1]]]
+             if (length(vif@excluded) > 0) x[[as.character(vif@results[,1])]]
              else x
            }
 )
@@ -58,7 +58,7 @@ setMethod ('exclude' ,signature(x='RasterBrick', vif='missing'),
              if(missing(th)) th <- 10
              vif <- vifstep(x,th=th)
              print(vif)
-             if (length(vif@excluded) > 0) brick(x[[vif@results[,1]]])
+             if (length(vif@excluded) > 0) brick(x[[as.character(vif@results[,1])]])
              else x
            }
 )
@@ -69,7 +69,7 @@ setMethod ('exclude' ,signature(x='data.frame', vif='missing'),
              if(missing(th)) th <- 10
              vif <- vifstep(x,th=th)
              print(vif)
-             if (length(vif@excluded) > 0) x[,vif@results[,1]]
+             if (length(vif@excluded) > 0) x[,as.character(vif@results[,1])]
              else x
            }
 )
@@ -80,7 +80,7 @@ setMethod ('exclude' ,signature(x='matrix', vif='missing'),
              if(missing(th)) th <- 10
              vif <- vifstep(x,th=th)
              print(vif)
-             if (length(vif@excluded) > 0) x[,vif@results[,1]]
+             if (length(vif@excluded) > 0) x[,as.character(vif@results[,1])]
              else x
            }
 )
